<?php

namespace Assetdocs\Incidentreport\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Incidentreport\Http\Requests\IncidentreportAdminWebRequest;
use Assetdocs\Incidentreport\Interfaces\IncidentreportRepositoryInterface;
use Assetdocs\Incidentreport\Models\Incidentreport;

/**
 * Admin web controller class.
 */
class IncidentreportAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize incidentreport controller.
     *
     * @param type IncidentreportRepositoryInterface $incidentreport
     *
     * @return type
     */
    public function __construct(IncidentreportRepositoryInterface $incidentreport)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $incidentreport;
        parent::__construct();
    }

    /**
     * Display a list of incidentreport.
     *
     * @return Response
     */
    public function index(IncidentreportAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $incidentreports  = $this->repository
            ->pushCriteria(new \Assetdocs\Incidentreport\Repositories\Criteria\IncidentreportAdminCriteria())
                ->setPresenter('\\Assetdocs\\Incidentreport\\Repositories\\Presenter\\IncidentreportListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $incidentreports['recordsTotal']    = $incidentreports['meta']['pagination']['total'];
            $incidentreports['recordsFiltered'] = $incidentreports['meta']['pagination']['total'];
            $incidentreports['request']         = $request->all();
            return response()->json($incidentreports, 200);

        }

        $this   ->theme->prependTitle(trans('incidentreport::incidentreport.names').' :: ');
        return $this->theme->of('incidentreport::admin.incidentreport.index')->render();
    }

    /**
     * Display incidentreport.
     *
     * @param Request $request
     * @param Model   $incidentreport
     *
     * @return Response
     */
    public function show(IncidentreportAdminWebRequest $request, Incidentreport $incidentreport)
    {
        if (!$incidentreport->exists) {
            return response()->view('incidentreport::admin.incidentreport.new', compact('incidentreport'));
        }

        Form::populate($incidentreport);
        return response()->view('incidentreport::admin.incidentreport.show', compact('incidentreport'));
    }

    /**
     * Show the form for creating a new incidentreport.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(IncidentreportAdminWebRequest $request)
    {

        $incidentreport = $this->repository->newInstance([]);

        Form::populate($incidentreport);

        return response()->view('incidentreport::admin.incidentreport.create', compact('incidentreport'));

    }

    /**
     * Create new incidentreport.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IncidentreportAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $incidentreport          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('incidentreport::incidentreport.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/incidentreport/incidentreport/'.$incidentreport->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show incidentreport for editing.
     *
     * @param Request $request
     * @param Model   $incidentreport
     *
     * @return Response
     */
    public function edit(IncidentreportAdminWebRequest $request, Incidentreport $incidentreport)
    {
        Form::populate($incidentreport);
        return  response()->view('incidentreport::admin.incidentreport.edit', compact('incidentreport'));
    }

    /**
     * Update the incidentreport.
     *
     * @param Request $request
     * @param Model   $incidentreport
     *
     * @return Response
     */
    public function update(IncidentreportAdminWebRequest $request, Incidentreport $incidentreport)
    {
        try {

            $attributes = $request->all();

            $incidentreport->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('incidentreport::incidentreport.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/incidentreport/incidentreport/'.$incidentreport->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/incidentreport/incidentreport/'.$incidentreport->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the incidentreport.
     *
     * @param Model   $incidentreport
     *
     * @return Response
     */
    public function destroy(IncidentreportAdminWebRequest $request, Incidentreport $incidentreport)
    {

        try {

            $t = $incidentreport->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('incidentreport::incidentreport.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/incidentreport/incidentreport/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/incidentreport/incidentreport/'.$incidentreport->getRouteKey()),
            ], 400);
        }
    }
}
